pub struct sockaddr_storage {
pub ss_family: sa_family_t,
/* private fields */
}Expand description
See https://pubs.opengroup.org/onlinepubs/9799919799/basedefs/sys_socket.h.html. Opaque storage large enough to hold any protocol specific address structure.
Implementation notes
- The total size of this struct is 128 bytes which is based off of
muslandglibc - The underscore fields are implementation specific details for padding that may change
usizeis used because it’s the width of a pointer for a given platform- The order of the fields is important because the bytes in the padding will be cast to and from protocol structs in C
cbindgen:ignore
Fields
ss_family: sa_family_tAddress family.